# Release 0.8.27

!!!tip inline end "Need Help?"
    The SuperCowPowers team is happy to give any assistance needed when setting up AWS and Workbench. So please contact us at [workbench@supercowpowers.com](mailto:workbench@supercowpowers.com) or on chat us up on [Discord](https://discord.gg/WHAJuz8sw8) 

The Workbench framework continues to flex to support different real world use cases when operating a set of production machine learning pipelines.

**Note:** These release notes cover the changes from `0.8.23` to `0.8.27`


### General
- Plugin Launcher: A flexible way to test plugins
- FeatureSpaceProximity (FSP): A Class for investigating feature space, neighbors, distances, etc.
- ProximityGraph: A class to construct NetworkX Graphs. Uses the FSP class to pull neighbors, contruct edges via 'distances', etc.
- Case


### API Changes

- **KNNSpider() --> FeatureSpaceProximity()**
    
    If you were previously using the `KNNSpider` that class has been replaced with `FeatureSpaceProximity`. The API is also a bit different please see the documentation on the [FeatureSpaceProximity Class](../../data_algorithms/dataframes/overview.md).
	
### Minor Improvements
The model scripts used in deployed AWS Endpoints are now case-insensitive. In general this should make the use of the endpoints a bit more flexible for End-User Applications to hit the endpoints with less pre-processing of their column names.

CloudWatch default buffers have been increased to 60 seconds as we appears to have been hitting some AWS limits with running 10 concurrent glue jobs.

## Questions?
<img align="right" src="../../../images/scp.png" width="180">

The SuperCowPowers team is happy to answer any questions you may have about AWS and Workbench. Please contact us at [workbench@supercowpowers.com](mailto:workbench@supercowpowers.com) or on chat us up on [Discord](https://discord.gg/WHAJuz8sw8) 


